from sqlmodel import Session
from backend.models.models import (
    User,
    Shop,
    Category,
    Product,
    ProductImage,
    Order,
    OrderItem,
)
from backend.utils.hashing import hash_password


def insert_dummy_data(session: Session):
    if not session.query(User).first():
        users = [
            User(
                username="string",
                email="user@example.com",
                password=hash_password("string"),
                role="customer",
            ),
            User(
                username="shop_owner",
                email="owner@example.com",
                password=hash_password("string"),
                role="shop_owner",
            ),
        ]
        session.add_all(users)
        session.commit()

    if not session.query(Shop).first():
        shops = [
            Shop(
                owner_id=2,
                name=f"Shop{i}",
                description=f"Description for Shop {i}",
                image_url="app/static/default/default_shop.png",
            )
            for i in range(1, 6)
        ]
        session.add_all(shops)
        session.commit()

    if not session.query(Category).first():
        categories = [Category(name=f"Category{i}") for i in range(1, 6)]
        session.add_all(categories)
        session.commit()

    if not session.query(Product).first():
        products = [
            Product(
                shop_id=i,
                category_id=i,
                name=f"Product{i}",
                description=f"Description for Product {i}",
                price=99.99 + i,
                stock=10 * i,
            )
            for i in range(1, 6)
        ]
        session.add_all(products)
        session.commit()

    if not session.query(ProductImage).first():
        images = [
            ProductImage(
                product_id=i, image_url="app/static/default/default_product.png"
            )
            for i in range(1, 6)
        ]
        session.add_all(images)
        session.commit()

    if not session.query(Order).first():
        orders = [
            Order(user_id=1, shop_id=i, total_price=100 + (i * 50), status="pending")
            for i in range(1, 6)
        ]
        session.add_all(orders)
        session.commit()

    if not session.query(OrderItem).first():
        order_items = [
            OrderItem(order_id=i, product_id=i, quantity=i, price=99.99 + i)
            for i in range(1, 6)
        ]
        session.add_all(order_items)
        session.commit()
