import customtkinter as ctk
from tkinter import messagebox
from utils.api_requests import login_api  # Import the login function from login_api.py


def login_frame(parent, switch_func, API_URL):
    frame = ctk.CTkFrame(parent)

    def login():
        email = entry_email.get()
        password = entry_password.get()

        if not email or not password:
            messagebox.showwarning("Input Error", "Both fields are required!")
            return

        # Call the API function from login_api.py
        status_code, response_data = login_api(email, password, API_URL)

        if status_code == 200:
            access_token = response_data.get("access_token")
            messagebox.showinfo("Login Successful", f"Welcome back, {email}!")
            switch_func("view_shop", access_token)
            print(f"Access Token in login: {access_token}")  # Debugging line
        else:
            messagebox.showerror(
                "Login Failed", response_data.get("detail", "Invalid credentials")
            )

    ctk.CTkLabel(frame, text="Login", font=("Helvetica", 18, "bold")).pack(pady=10)

    ctk.CTkLabel(frame, text="Email:").pack(pady=5)
    entry_email = ctk.CTkEntry(frame)
    entry_email.pack(pady=5)

    ctk.CTkLabel(frame, text="Password:").pack(pady=5)
    entry_password = ctk.CTkEntry(frame, show="*")
    entry_password.pack(pady=5)

    ctk.CTkButton(frame, text="Login", command=login).pack(pady=15)

    ctk.CTkButton(
        frame,
        text="Don't have an account? Register",
        command=lambda: switch_func("register"),
    ).pack()

    return frame
